@@ -8,7 +8,7 @@
 # starting this program. Ports used are the defaults for gqrx and Hamlib.
 #
 #
-# Copyright 2017, 2018 Simon Kennedy, G0FCU, g0fcu at g0fcu.com
+# Copyright 2017-2023 Simon Kennedy, G0FCU, g0fcu at g0fcu.com
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -26,7 +26,16 @@ import sys
 import socket
 import time
 from os.path import expanduser
-from PyQt5 import QtGui, QtCore, QtWidgets
+
+from PyQt5 import QtCore, QtGui, QtWidgets
+#from PyQt5.QtCore import *
+#from PyQt5.QtGui import *
+#from PyQt5.QtWidgets import *
+
+
+from PyQt5.QtWidgets import (
+    QApplication, QDialog, QMessageBox
+)
 from PyQt5.QtCore import QThread
 from gqrxHamlib import gqrxHamlibGUI
 #import xmlrpc.client
@@ -34,16 +43,21 @@ from gqrxHamlib import gqrxHamlibGUI
 class startControl(QThread):
     reportErr = QtCore.pyqtSignal(str, str)
     
-    def __init__(self, control, oneoff, gqrxIPv, gqrxPortv, hamlibIPv, hamlibPortv,  modev, ifModev, ifFreqv):
+    def __init__(self, control, oneoff, gqrxIPv, gqrxPortv, hamlibIPv, hamlibPortv, modev, ifModev, ifFreqv):
         QThread.__init__(self)
         self.control = control
         self.oneoff = oneoff
+        #self.fldigi_option_set = 1
         self.gqrxIPv = gqrxIPv
         self.gqrxPortv = gqrxPortv
         self.hamlibIPv = hamlibIPv
         self.hamlibPortv = hamlibPortv
+        #self.fldigiIPv = fldigiIPv
+        #self.fldigiPortv = fldigiPortv
+        #self.fldigiv = fldigiv
         self.modev = modev
         TCP_IP = '127.0.0.1'
+        #FLDIGI_PORT = 7362
         
         self.ifFreqv = ifFreqv
         self.ifModev = ifModev
@@ -57,33 +71,17 @@ class startControl(QThread):
     def run(self):    
         HAMLIB_PORT = 4532
         GQRX_PORT = 7356
-        sockGqrx = 0
-        sockHamlib = 0
+        FLRIG_PORT = 7362
         #self.setupUi(self)
+        #if self.fldigiv == 'Y':
+            #endpoint = 'flrig'
+            #RIG_PORT = FLRIG_PORT
+            #TCP_IP = self.fldigiIPv
+            #self.server = xmlrpc.client.ServerProxy('http://{}:{}/'.format(TCP_IP, RIG_PORT))
+        #else:
         endpoint = 'hamlib'
         RIG_PORT = HAMLIB_PORT
         TCP_IP = self.hamlibIPv
-        #TCP_IP = '127.0.0.1'
-        #HAMLIB_PORT = 4532
-        #self.gqrxIPv = '127.0.0.1'
-        #GQRX_PORT = 7356
-        #TCP_IP = "'127.0.0.1'"
-        #HAMLIB_PORT = "'9537'"
-        #self.gqrxIPv = "'127.0.0.1'"
-        #GQRX_PORT = "'9536'"
-        print (TCP_IP, HAMLIB_PORT, self.gqrxIPv, GQRX_PORT)
-        sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
-            #sockHamlib = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
-            # Bind the socket to the port
-            #server_address1 = (TCP_IP, HAMLIB_PORT)
-            #sockHamlib.connect(server_address)
-            #sockHamlib.bind(server_address1)
-        #sockGqrx = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
-        # Bind the socket to the port
-        #server_address2 = (self.gqrxIPv, GQRX_PORT)
-        #sockGqrx.bind(server_address2)
-        #sockGqrx.connect(server_address)
-        sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
         rig_freq = 0
         gqrx_freq = 0
         old_rig_freq = 0
@@ -94,188 +92,179 @@ class startControl(QThread):
         old_rig_mode = ''
         old_gqrx_mode = ''
         data = 0
-                
-        gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', sockGqrx)
-        print (gqrx_freq)
-        if gqrx_freq.find('\n') != -1:
+        gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx')
+        if gqrx_freq.decode("utf-8").find('\n') != -1:
+            print('1111', gqrx_freq.decode("utf-8"))
             gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
+            print('2222', gqrx_freq)
         else:
             print('ERROR')
         old_gqrx_freq = 0 #gqrx_freq
                  
         while self.control > 0:       
-            time.sleep(0.2)
+            time.sleep(0.1)
             if self.control == 1 or self.control == 3:
                 #rig_freq = str(self.getfreq(TCP_IP, RIG_PORT, endpoint))
-                rig_freq = self.getfreq(TCP_IP, RIG_PORT, endpoint, sockHamlib)
-                #print (rig_freq)
-                if rig_freq[:4] != 'RPRT':
-                    if endpoint == 'hamlib':
-                        if rig_freq.find('\n') != -1:
-                            rig_freq = rig_freq[0:rig_freq.find('\n')]
-                    else:
-                        rig_freqStr = repr(rig_freq)
-                        if rig_freqStr.find('.') != -1:
-                            rig_freqStr = rig_freqStr[0:rig_freqStr.find('.')]
-                            rig_freq = int(rig_freqStr)
-                    if rig_freq != old_rig_freq:
-                        # set gqrx to Hamlib/flrig frequency
-                        print ('call set gqrx freq', self.gqrxIPv, GQRX_PORT, 'gqrx', '@', rig_freq, '@', sockGqrx)
-                        self.setfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', int(rig_freq), sockGqrx)
-                        #print('SetFreq Return Code from GQRX: {0}'.format(rc))
-                        old_rig_freq = rig_freq
-                        old_gqrx_freq = gqrx_freq
-                    if self.modev == 'Y':
-                        rig_mode = self.getmode(TCP_IP, RIG_PORT, endpoint, sockHamlib)[:3]
-                        if rig_mode != old_rig_mode:
-                            set_mode = rig_mode
-                            # set gqrx to Hamlib frequency
-                            self.setmode(self.gqrxIPv, GQRX_PORT, 'gqrx', set_mode, sockGqrx)
-                            old_rig_mode = rig_mode
-                            old_gqrx_mode = rig_mode
+                rig_freq = self.getfreq(TCP_IP, RIG_PORT, endpoint)
+                if endpoint == 'hamlib':
+                    print('rig freq', rig_freq)
+                    if rig_freq.find('\n') != -1:
+                        rig_freq = rig_freq[0:rig_freq.find('\n')]
+                        print('rig freq', rig_freq)
+                else:
+                    if rig_freq.find('.') != -1:
+                        rig_freq = rig_freq[0:rig_freq.find('.')]
+                print('rig freq', rig_freq)
+                if rig_freq != old_rig_freq:
+                    # set gqrx to Hamlib/flrig frequency
+                    self.setfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', float(rig_freq))
+                    #print('SetFreq Return Code from GQRX: {0}'.format(rc))
+                    old_rig_freq = rig_freq
+                    old_gqrx_freq = rig_freq
+                if self.modev == 'Y':
+                    rig_mode = self.getmode(TCP_IP, RIG_PORT, endpoint)[:3]
+                    if rig_mode != old_rig_mode:
+                        set_mode = rig_mode
+                        # set gqrx to Hamlib frequency
+                        self.setmode(self.gqrxIPv, GQRX_PORT, 'gqrx', set_mode)
+                        old_rig_mode = rig_mode
+                        old_gqrx_mode = rig_mode
             
        
             if self.control == 1 or self.control == 2:
-                gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', sockGqrx)
-                #print (gqrx_freq)
-                if gqrx_freq[:4] != 'RPRT':
-                    if gqrx_freq.find('\n') != -1:
-                        gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
-                    if self.control == 2 and self.ifModev == 'Y':
-                        if gqrx_freq != old_gqrx_freq:
-                            if gqrx_freq > self.ifFreqv:
-                                ifDiff = int(gqrx_freq) - int(self.ifFreqv)
-                            else:
-                                ifDiff = 0 - (int(self.ifFreqv) - int(gqrx_freq))
-                            #print 'ifDiff', ifDiff,'ifFreqv',int(self.ifFreqv),'gqrx_freq',int(gqrx_freq)
-                            rig_freq = str(self.getfreq(TCP_IP, RIG_PORT, endpoint, sockHamlib))
-                            if endpoint == 'hamlib':
-                                 if rig_freq.find('\n') != -1:
-                                    rig_freq = rig_freq[0:rig_freq.find('\n')]
-                            else:
-                                if rig_freq.find('.') != -1:
-                                    rig_freq = rig_freq[0:rig_freq.find('.')]
+                gqrx_freq = str(self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx'))
+                if gqrx_freq.find('\n') != -1:
+                    gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
+                if self.control == 2 and self.ifModev == 'Y':
+                    if gqrx_freq != old_gqrx_freq:
+                        if gqrx_freq > self.ifFreqv:
+                            ifDiff = int(gqrx_freq) - int(self.ifFreqv)
+                        else:
+                            ifDiff = 0 - (int(self.ifFreqv) - int(gqrx_freq))
+                        #print 'ifDiff', ifDiff,'ifFreqv',int(self.ifFreqv),'gqrx_freq',int(gqrx_freq)
+                        rig_freq = str(self.getfreq(TCP_IP, RIG_PORT, endpoint))
+                        if endpoint == 'hamlib':
+                             if rig_freq.find('\n') != -1:
+                                rig_freq = rig_freq[0:rig_freq.find('\n')]
+                        else:
+                            if rig_freq.find('.') != -1:
+                                rig_freq = rig_freq[0:rig_freq.find('.')]
+                        
+                        self.setfreq(TCP_IP, RIG_PORT, endpoint, float(int(rig_freq) + int(ifDiff)))
+                        #print 'calc', float(int(rig_freq) - int(ifDiff))
+                        #old_gqrx_freq = self.ifFreqv
+                        gqrx_freq = self.ifFreqv
+                        self.setfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', float(gqrx_freq))
                             
-                            self.setfreq(TCP_IP, RIG_PORT, endpoint, float(int(rig_freq) + int(ifDiff)), sockHamlib)
-                            #print 'calc', float(int(rig_freq) - int(ifDiff))
-                            #old_gqrx_freq = self.ifFreqv
-                            gqrx_freq = self.ifFreqv
-                            self.setfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', float(gqrx_freq), sockGqrx)
-                                
-                        if self.modev == 'Y':        
-                            gqrx_mode = self.getmode(self.gqrxIPv, GQRX_PORT, 'gqrx', sockGqrx)[:3]
-                            if gqrx_mode != old_gqrx_mode:
-                                # set Hamlib to gqrx frequency
-                                self.setmode(TCP_IP, RIG_PORT, endpoint, gqrx_mode, sockGqrx)
-                                #print('SetMode Return Code from Hamlib: {0}'.format(rc))
-                                old_gqrx_mode = gqrx_mode
-                                old_rig_mode = gqrx_mode  
-                    else:
-                        #print (gqrx_freq)
-                        if gqrx_freq[:4] != 'RPRT':
-                            if gqrx_freq != old_gqrx_freq:
-                                # set Hamlib to gqrx frequency
-                                self.setfreq(TCP_IP, RIG_PORT, endpoint, float(gqrx_freq), sockHamlib)
-                                old_gqrx_freq = gqrx_freq
-                                old_rig_freq = gqrx_freq
-                            if self.modev == 'Y':        
-                                gqrx_mode = self.getmode(self.gqrxIPv, GQRX_PORT, 'gqrx', sockGqrx)[:3]
-        
-                                if gqrx_mode != old_gqrx_mode:
-                                    # set Hamlib to gqrx frequency
-                                    self.setmode(TCP_IP, RIG_PORT, endpoint, gqrx_mode, sockHamlib)
-                                    #print('SetMode Return Code from Hamlib: {0}'.format(rc))
-                                    old_gqrx_mode = gqrx_mode
-                                    old_rig_mode = gqrx_mode 
+                    if self.modev == 'Y':        
+                        gqrx_mode = self.getmode(self.gqrxIPv, GQRX_PORT, 'gqrx')[:3]
+                        if gqrx_mode != old_gqrx_mode:
+                            # set Hamlib to gqrx frequency
+                            self.setmode(TCP_IP, RIG_PORT, endpoint, gqrx_mode)
+                            #print('SetMode Return Code from Hamlib: {0}'.format(rc))
+                            old_gqrx_mode = gqrx_mode
+                            old_rig_mode = gqrx_mode  
+                else:
+                    if gqrx_freq != old_gqrx_freq:
+                        # set Hamlib to gqrx frequency
+                        self.setfreq(TCP_IP, RIG_PORT, endpoint, float(gqrx_freq))
+                        old_gqrx_freq = gqrx_freq
+                        old_rig_freq = gqrx_freq
+                    if self.modev == 'Y':        
+                        gqrx_mode = self.getmode(self.gqrxIPv, GQRX_PORT, 'gqrx')[:3]
+                        if gqrx_mode != old_gqrx_mode:
+                            # set Hamlib to gqrx frequency
+                            self.setmode(TCP_IP, RIG_PORT, endpoint, gqrx_mode)
+                            #print('SetMode Return Code from Hamlib: {0}'.format(rc))
+                            old_gqrx_mode = gqrx_mode
+                            old_rig_mode = gqrx_mode 
                             
             if self.oneoff == True:
                 return
     
       
-    def getfreq(self, IP, PORT, endpoint, sock):
+    def getfreq(self, IP, PORT, endpoint):
         if endpoint == 'hamlib' or endpoint == 'gqrx':
-            #sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
             # Bind the socket to the port
-            #server_address = (IP, PORT)
-            #sock.connect(server_address)
+            server_address = (IP, PORT)
+            sock.connect(server_address)
             sock.sendall(b'f\n')
             data = sock.recv(16)
             #print ('get', endpoint, ' ',IP ,' ',data)
             if data[:4] == 'RPRT':
                 if data[:6] != 'RPRT 0':
                     self.reportErr.emit(endpoint, str(data))
-                    return data
-            #sock.close()
-            data = data.decode("utf-8")
+                    return
+            sock.close()
         else:
             data = 0
             data = self.server.main.get_frequency()
         return data
     
-    def setfreq(self, IP, PORT, endpoint, freq, sock):
+    def setfreq(self, IP, PORT, endpoint, freq):
         if endpoint == 'hamlib' or endpoint == 'gqrx':
-            #sock = socket.socket(socket.AF_INET, 
-            #             socket.SOCK_STREAM) 
+            sock = socket.socket(socket.AF_INET, 
+                         socket.SOCK_STREAM) 
             # Bind the socket to the port
-            #server_address = (IP, PORT)
-            #sock.connect(server_address)
+            server_address = (IP, PORT)
+            sock.connect(server_address)
             build_msg = 'F ' + str(freq) + '\n'
-            MESSAGE = bytes(build_msg, 'utf-8')
-            #print(sock)
+            MESSAGE = bytes(build_msg)
             sock.sendall(MESSAGE)
-            print ('set', endpoint, ' ',IP ,' ',build_msg,MESSAGE)
+            #print ('set', endpoint, ' ',IP ,' ',build_msg,MESSAGE)
             data = sock.recv(16)
-            print ('set', endpoint, ' ',IP ,' ',data)
+            #print ('set', endpoint, ' ',IP ,' ',data)
             if data[:4] == 'RPRT':
-                 if data[:6] != 'RPRT 0':
-                     self.reportErr.emit(endpoint, str(data))
-                     return data
-                    ##sock.close()
+                if data[:6] != 'RPRT 0':
+                    self.reportErr.emit(endpoint, str(data))
+                    return
+            sock.close()
         else:
             data = self.server.main.set_frequency(float(freq))
         return data
     
-    def getmode(self, IP, PORT, endpoint, sock):
+    def getmode(self, IP, PORT, endpoint):
         if endpoint == 'hamlib' or endpoint == 'gqrx':
-            #sock = socket.socket(socket.AF_INET, 
-            #                 socket.SOCK_STREAM) 
+            sock = socket.socket(socket.AF_INET, 
+                             socket.SOCK_STREAM) 
             # Bind the socket to the port
-            #server_address = (IP, PORT)
-            #sock.connect(server_address)
+            server_address = (IP, PORT)
+            sock.connect(server_address)
             sock.sendall(b'm\n')
             data = sock.recv(16)
             if data[:4] == 'RPRT':
                 if data[:6] != 'RPRT 0':
                     self.reportErr.emit(endpoint, str(data))
-                    return data
-            #sock.close()
-            data = data.decode("utf-8")
+                    return
+            sock.close()
         else:
             data = self.server.rig.get_mode(str())  
         return data
     
-    def setmode(self, IP, PORT, endpoint, mode, sock):
+    def setmode(self, IP, PORT, endpoint, mode):
         if endpoint == 'hamlib' or endpoint == 'gqrx':
-            #sock = socket.socket(socket.AF_INET, 
-            #                 socket.SOCK_STREAM) 
+            sock = socket.socket(socket.AF_INET, 
+                             socket.SOCK_STREAM) 
             # Bind the socket to the port
-            #server_address = (IP, PORT)
-            #sock.connect(server_address)
+            server_address = (IP, PORT)
+            sock.connect(server_address)
             build_msg = 'M ' + str(mode) + ' 0' + '\n'
-            MESSAGE = bytes(build_msg, "utf-8")
+            MESSAGE = bytes(build_msg)
             sock.sendall(MESSAGE)
             data = ''
             data = sock.recv(7)
             if data[:4] == 'RPRT':
                 if data[:6] != 'RPRT 0':
                     self.reportErr.emit(endpoint, str(data))
-                    return data
-            #sock.close()
+                    return
+            sock.close()
         else:
             data = self.server.rig.set_mode(str(mode))
         return data
-       
-class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
+
+#class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):    
+class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):      
     def __init__(self):
         super(self.__class__, self).__init__()
         self.setupUi(self)
@@ -300,13 +289,12 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton.clicked.connect(self.gqrxhamlibSync)
             self.pushButton_3.clicked.connect(self.hamlibControl)
             self.pushButton_4.clicked.connect(self.hamlibControlOneoff)
-            self.pushButton_8.clicked.connect(self.hamlibControlOneoff)
              
         self.pushButton_2.clicked.connect(self.gqrxControl)
         self.pushButton_6.clicked.connect(self.gqrxControlOneoff)
         
     def reportErrMsg(self, source, rc):
-        self.errorMsg.setText('Error, return code ' + rc + ' reported by ' + source) 
+        self.errorMsg.setText('Error, return code ' + rc + ' reported by ' + source)
                     
     def stopThread(self):
         self.btn_stop.setStyleSheet("background-color: red")
@@ -391,7 +379,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: red")
-            self.pushButton_8.setStyleSheet("background-color: red")
         self.pushButton_2.setStyleSheet("background-color: green")
         self.pushButton_6.setStyleSheet("background-color: green")
         self.control = 3
@@ -402,7 +389,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
         self.pushButton_4.setStyleSheet("background-color: green")
-        self.pushButton_8.setStyleSheet("background-color: green")
         self.control = 0
         
     def readConfig(self):
@@ -416,7 +402,8 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             cf.close()
             cf = open(homedir + '/.config/.gqrxHamlib.config', 'r')
         configLine = cf.read()
-        # handle upgrade from 2.5 to 2.6 where there are two additional parameters for IF panaadaptor functionality
+        # handle upgrade from 2.5 to 2.6 where there are two additional parameters for IF panadaptor functionality
+        # and from 3.1 to 3.2 where the fldigi stuff was removed
         countitems = len(configLine.split(','))
         if countitems == 8:
             self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev = configLine.split(',')
@@ -433,7 +420,15 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         self.gqrxPort.setText(self.gqrxPortv)
         self.hamlibIP.setText(self.hamlibIPv)
         self.hamlibPort.setText(self.hamlibPortv)
+        #self.fldigiIP.setText(self.fldigiIPv)
+        #self.fldigiPort.setText(self.fldigiPortv)
         self.if_freq.setText(self.ifFreqv)
+        #if self.fldigiv == 'Y':
+            #self.fldigi.setChecked(True)
+            # change labels
+        #else:
+            #self.fldigi.setChecked(False)
+            # change labels
         if self.modev == 'Y':
             self.mode.setChecked(True)
         else:
@@ -444,7 +439,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: grey")
             self.pushButton_4.setStyleSheet("background-color: grey")
-            self.pushButton_8.setStyleSheet("background-color: grey")
             self.pushButton_6.setStyleSheet("background-color: green")
         else:
             self.panadaptor.setChecked(False)
@@ -452,7 +446,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: green")
-            self.pushButton_8.setStyleSheet("background-color: green")
             self.pushButton_6.setStyleSheet("background-color: green")
         cf.close()
             
@@ -463,6 +456,25 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         self.gqrxPortv = self.gqrxPort.text()
         self.hamlibIPv = self.hamlibIP.text()
         self.hamlibPortv = self.hamlibPort.text()
+        #self.fldigiIPv = self.fldigiIP.text()
+        #self.fldigiPortv = self.fldigiPort.text()
+        self.ifFreqv = self.if_freq.text()
+        #if self.fldigi.isChecked():
+            #self.fldigiv = 'Y'
+            # change labels
+            #self.pushButton_6.setText('gqrx-->flrig')
+            #self.pushButton_4.setText('gqrx<--flrig')
+            #self.pushButton.setText('gqrx<-->flrig')
+            #self.pushButton_2.setText('gqrx-->flrig')
+            #self.pushButton_3.setText('gqrx<--flrig')
+        #else:
+            #self.fldigiv = 'N'
+        self.pushButton_6.setText('gqrx-->Hamlib')
+        self.pushButton_4.setText('gqrx<--Hamlib')
+        self.pushButton.setText('gqrx<-->Hamlib')
+        self.pushButton_2.setText('gqrx-->Hamlib')
+        self.pushButton_3.setText('gqrx<--Hamlib')
+            #change labels
         if self.mode.isChecked():
             self.modev = 'Y'
         else:
@@ -473,7 +485,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: grey")
             self.pushButton_4.setStyleSheet("background-color: grey")
-            self.pushButton_8.setStyleSheet("background-color: grey")
             self.pushButton_6.setStyleSheet("background-color: green")
         else:
             self.ifModev = 'N'
@@ -481,7 +492,6 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: green")
-            self.pushButton_8.setStyleSheet("background-color: green")
             self.pushButton_6.setStyleSheet("background-color: green")
         configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.modev+','+self.ifModev+','+self.ifFreqv
         cf.write(configLine)
@@ -497,7 +507,8 @@ class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.stopThread()
 
 def main():
-    app = QtWidgets.QApplication(sys.argv)
+
+    app = QApplication(sys.argv)
     form = gqrxHamlib()
     form.show()
     app.exec_()
